plot bounds on the quantile of the treatment effect using ggplot2
ggCSABounds(csaboundsobj, tau = seq(0.05, 0.95, 0.05), wdbounds = FALSE,
otherdist1 = NULL, otherdist2 = NULL)an object returned from the csa.bounds method
vector of values between 0 and 1 to plot quantiles for
boolean whether or not to also plot Williamson-Downs bounds
optional ecdf of the distribution of the treatment effect under cross sectional rank invariance
optional ecdf of the distribution of the treatment effect under panel rank invariance